==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/ExtendsHashTable.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.Collections;

using j4o.lang;
using j4o.util;
namespace com.db4o.test {

   public class ExtendsHashTable: System.Collections.Hashtable {
      
      public ExtendsHashTable() : base() {
      }
      
      public void store() {
         Tester.deleteAllInstances(this);
         Add(System.Convert.ToInt32(1), "one");
         Add(System.Convert.ToInt32(2), "two");
         Add(System.Convert.ToInt32(3), "three");
         Tester.store(this);
      }
      
      public void test() {
         ExtendsHashTable ehm1 = (ExtendsHashTable)Tester.getOne(this);
         Tester.ensure(ehm1[System.Convert.ToInt32(1)].Equals("one"));
         Tester.ensure(ehm1[System.Convert.ToInt32(3)].Equals("three"));
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/ExtendsHashTable.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.Collections;

using j4o.lang;
using j4o.util;
namespace com.db4o.test {

   public class ExtendsHashTable: System.Collections.Hashtable {
      
      public ExtendsHashTable() : base() {
      }
      
      public void Store() {
         Tester.DeleteAllInstances(this);
         Add(System.Convert.ToInt32(1), "one");
         Add(System.Convert.ToInt32(2), "two");
         Add(System.Convert.ToInt32(3), "three");
         Tester.Store(this);
      }
      
      public void Test() {
         ExtendsHashTable ehm1 = (ExtendsHashTable)Tester.GetOne(this);
         Tester.Ensure(ehm1[System.Convert.ToInt32(1)].Equals("one"));
         Tester.Ensure(ehm1[System.Convert.ToInt32(3)].Equals("three"));
      }
   }
}
